@@ -1,6 +1,6 @@
 # grDevices: col2rgb, palette, rgb
 
-dhist <- function(x,fac,col,legend,pos.legend,title.legend=NULL,lab.legend=NULL,xlab,ylab=NULL,
+dhist <- function(x,fac,col=NULL,legend,pos.legend,title.legend=NULL,lab.legend=NULL,xlab,ylab=NULL,
   drawextaxes=TRUE,drawintaxes=FALSE,xlim=NULL,...) {
   ymax <- integer(nlevels(fac))
   for (i in 1:nlevels(fac)) {
@@ -20,13 +20,10 @@ dhist <- function(x,fac,col,legend,pos.legend,title.legend=NULL,lab.legend=NULL,
   lab.line <- c(ifelse(drawextaxes,3,1.2),ifelse(drawextaxes,3,0.6))
   mtext(c(xlab,ylab),side=c(1,2),line=lab.line,at=c(mean(range(x)),mean(c(0,max(ymax)))))
   dens <- tapply(x,fac,function(x) density(x))
-  if (!is.numeric(col)) {
-    col3 <- col4 <- col
-  } else {
-    col2 <- grDevices::col2rgb(grDevices::palette()[col])
-    col3 <- apply(col2,2,function(x) grDevices::rgb(x[1],x[2],x[3],alpha=0.4*255,maxColorValue=255))
-    col4 <- apply(col2,2,function(x) grDevices::rgb(x[1],x[2],x[3],alpha=255,maxColorValue=255))  
-  }
+  if (is.null(col)) {col <- rep(grDevices::palette(),nlevels(fac)%/%length(grDevices::palette())+1)[1:nlevels(fac)]}
+  col2 <- grDevices::col2rgb(col)
+  col3 <- apply(col2,2,function(x) grDevices::rgb(x[1],x[2],x[3],alpha=0.4*255,maxColorValue=255))
+  col4 <- apply(col2,2,function(x) grDevices::rgb(x[1],x[2],x[3],alpha=255,maxColorValue=255)) 
   for (i in 1:nlevels(fac)) {
     d <- dens[[i]]
     polygon(d$x,d$y,col=col3[i],border=NA)
